==> react-native-dc-0.0.8.tgz: package/lib/modules/FileModule.js <==
// 对原生接口的封装
import {NativeModules} from 'react-native';
const {FileModule} = NativeModules;
/**
 * 文件相关接口
 */
// 新增文件
export const DCaddFile = (readPath, enkey) => {
  return new Promise(resolve => {
    const listenCallback = (status) => {
      console.log('file_AddFile listenCallback11111', status);
    };
    const successCallback = (cid) => {
      console.log('file_AddFile success', cid);
      resolve({cid});
    };
    const errorCallback = (error) => {
      console.log('file_AddFile error', error);
      resolve({error});
    };
    FileModule.file_AddFile(
      readPath,
      enkey,
      successCallback,
      errorCallback,
      listenCallback,
    );
  });
};

// 获取文件
export const DCgetFile = (cid, savePath, enkey) => {
  return new Promise((resolve, reject) => {
    const listenCallback = (status) => {
      console.log('file_GetFile listenCallback2222222', status);
    };
    const successCallback = () => {
      console.log('file_GetFile success');
      resolve({});
    };
    const errorCallback = (error) => {
      console.log('file_GetFile error', error);
      resolve({error});
    };
    FileModule.file_GetFile(
      cid,
      savePath,
      enkey,
      successCallback,
      errorCallback,
      listenCallback,
    );
  });
};

// 删除文件
export const DCdeleteFile = (cid) => {
  return new Promise((resolve, reject) => {
    const successCallback = () => {
      console.log('file_DeleteFile success');
      resolve({});
    };
    const errorCallback = (error) => {
      console.log('file_DeleteFile error', error);
      resolve({error});
    };
    FileModule.file_DeleteFile(cid, successCallback, errorCallback);
  });
};

//清理文件缓存文件
export const DCcleanFile = async () => {
  return new Promise((resolve, reject) => {
    const successCallback = (bool) => {
      console.log('file_CleanFile success ' + bool);
      resolve({bool});
    };
    const errorCallback = (error) => {
      console.log('file_CleanFile error', error);
      resolve({error});
    };
    FileModule.file_CleanFile(successCallback, errorCallback);
  });
};

==> react-native-dc-0.0.15.tgz: package/lib/modules/FileModule.js <==
// 对原生接口的封装
import {NativeModules} from 'react-native';
const {FileModule} = NativeModules;
/**
 * 文件相关接口
 */
// 新增文件
export const DCaddFile = (readPath, enkey) => {
  return new Promise(resolve => {
    const listenCallback = (info) => {
      console.log('file_AddFile listenCallback', info);
    };
    const successCallback = (cid) => {
      console.log('file_AddFile success', cid);
      resolve({cid});
    };
    const errorCallback = (error) => {
      console.log('file_AddFile error', error);
      resolve({error});
    };
    FileModule.file_AddFile(
      readPath,
      enkey,
      // listenCallback,
      successCallback,
      errorCallback,
    );
  });
};

// 获取文件
export const DCgetFile = (cid, savePath, enkey) => {
  return new Promise((resolve, reject) => {
    // const listenCallback = (status, size) => {
    //   console.log('addFile listenCallback', status, size);
    // };
    const successCallback = () => {
      console.log('file_GetFile success');
      resolve({});
    };
    const errorCallback = (error) => {
      console.log('file_GetFile error', error);
      resolve({error});
    };
    FileModule.file_GetFile(
      cid,
      savePath,
      enkey,
      // listenCallback,
      successCallback,
      errorCallback,
    );
  });
};

// 删除文件
export const DCdeleteFile = (cid) => {
  return new Promise((resolve, reject) => {
    const successCallback = () => {
      console.log('file_DeleteFile success');
      resolve({});
    };
    const errorCallback = (error) => {
      console.log('file_DeleteFile error', error);
      resolve({error});
    };
    FileModule.file_DeleteFile(cid, successCallback, errorCallback);
  });
};

//清理文件缓存文件
export const DCcleanFile = async () => {
  return new Promise((resolve, reject) => {
    const successCallback = (bool) => {
      console.log('file_CleanFile success ' + bool);
      resolve({bool});
    };
    const errorCallback = (error) => {
      console.log('file_CleanFile error', error);
      resolve({error});
    };
    FileModule.file_CleanFile(successCallback, errorCallback);
  });
};
